==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/corpbasicoutsite/CorpbasicoutsiteTextcardReqBean.java <==
package global.hh.openapi.sdk.api.bean.corpbasicoutsite;


/**
 * @description: 企业微信发送应用消息：文本卡片消息
 * @author: 777771
 * @date: 2022-39-20 16:39:26
 */
public class CorpbasicoutsiteTextcardReqBean {
    /**
     * 自建应用id
     */
    private String agentId;

    /**
     * 部门ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为@all时忽略本参数
     */
    private String toParty;

    /**
     * 成员ID列表（消息接收者，多个接收者用‘|’分隔，最多支持1000个）。特殊情况：指定为@all，则向该企业应用的全部成员发送
     */
    private String toUser;

    /**
     * 文本卡片消息内容
     */
    private CorpbasicoutsiteTextcardTextcardBean textcard;

    public CorpbasicoutsiteTextcardReqBean(){
    }

    public CorpbasicoutsiteTextcardReqBean(String agentId,String toParty,String toUser,CorpbasicoutsiteTextcardTextcardBean textcard){
        this.agentId=agentId;
        this.toParty=toParty;
        this.toUser=toUser;
        this.textcard=textcard;
    }

    private String getAgentId() {
        return agentId;
    }

    private void setAgentId(String agentId) {
        this.agentId = agentId;
    }
    private String getToParty() {
        return toParty;
    }

    private void setToParty(String toParty) {
        this.toParty = toParty;
    }
    private String getToUser() {
        return toUser;
    }

    private void setToUser(String toUser) {
        this.toUser = toUser;
    }
    private CorpbasicoutsiteTextcardTextcardBean getTextcard() {
        return textcard;
    }

    private void setTextcard(CorpbasicoutsiteTextcardTextcardBean textcard) {
        this.textcard = textcard;
    }
}

==> biostime-openapi-sdk-1.5.9.2-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/corpbasicoutsite/CorpbasicoutsiteTextcardReqBean.java <==
package global.hh.openapi.sdk.api.bean.corpbasicoutsite;


/**
 * @description: 企业微信发送应用消息：文本卡片消息
 * @author: 777771
 * @date: 2022-39-20 16:39:26
 */
public class CorpbasicoutsiteTextcardReqBean {
    /**
     * 自建应用id
     */
    private String agentId;

    /**
     * 部门ID列表，多个接收者用‘|’分隔，最多支持100个。当touser为@all时忽略本参数
     */
    private String toParty;

    /**
     * 成员ID列表（消息接收者，多个接收者用‘|’分隔，最多支持1000个）。特殊情况：指定为@all，则向该企业应用的全部成员发送
     */
    private String toUser;

    /**
     * 文本卡片消息内容
     */
    private CorpbasicoutsiteTextcardTextcardBean textcard;

    public CorpbasicoutsiteTextcardReqBean(){
    }

    public CorpbasicoutsiteTextcardReqBean(String agentId,String toParty,String toUser,CorpbasicoutsiteTextcardTextcardBean textcard){
        this.agentId=agentId;
        this.toParty=toParty;
        this.toUser=toUser;
        this.textcard=textcard;
    }

    public String getAgentId() {
        return agentId;
    }

    public void setAgentId(String agentId) {
        this.agentId = agentId;
    }
    public String getToParty() {
        return toParty;
    }

    public void setToParty(String toParty) {
        this.toParty = toParty;
    }
    public String getToUser() {
        return toUser;
    }

    public void setToUser(String toUser) {
        this.toUser = toUser;
    }
    public CorpbasicoutsiteTextcardTextcardBean getTextcard() {
        return textcard;
    }

    public void setTextcard(CorpbasicoutsiteTextcardTextcardBean textcard) {
        this.textcard = textcard;
    }
}
